# API

In addition to declaring a schema (which is intended to be language agnostic),
`useq-schema` offers a python API for working with
[`MDASequence`][useq.MDASequence] and [`MDAEvent`][useq.MDAEvent] objects.

::: useq.MDASequence
    options:
        show_signature: true
        show_signature_annotations: true


::: useq._mda_sequence.iter_sequence
    options:
        show_source: true
        show_signature: true
        show_signature_annotations: false
